---
title: "credits"
description: credit where credit is due.
kind: page
id: articles
layout:  page.haml
---

The contents of this site were derived from the 
[Project Gutenberg release of Walden](https://www.gutenberg.org/ebooks/205)
by Henry David Thoreau.

You can find the original, unmodified Project Gutenberg file
[here](/205-0.txt)

And the text of the Project Gutenberg license [here](/license.html)

Here is the original description of the book from Project Gutenberg:

    This eBook is for the use of anyone anywhere in the United States and
    most other parts of the world at no cost and with almost no restrictions
    whatsoever. You may copy it, give it away or re-use it under the terms
    of the Project Gutenberg License included with this eBook or online at
    www.gutenberg.org. If you are not located in the United States, you
    will have to check the laws of the country where you are located before
    using this eBook.
    
    Title: Walden
    
    Author: Henry David Thoreau
    
    Release Date: January, 1995 [eBook #205]
    [Most recently updated: January 28, 2021]
    
    Language: English
    
    Character set encoding: UTF-8
    
    Produced by: Judith Boss, and David Widger


